@@ -75,7 +75,6 @@ class Server(object):
     def on(self, event, handler=None):
         """Register an event handler.
 
-        This method can be used
         :param event: The event name. Can be ``'connect'``, ``'message'`` or
                       ``'disconnect'``.
         :param handler: The function that should be invoked to handle the
@@ -115,15 +114,20 @@ class Server(object):
             return set_handler
         set_handler(handler)
 
-    def send(self, sid, data):
+    def send(self, sid, data, binary=None):
         """Send a message to a client.
 
         :param sid: The session id of the recipient client.
         :param data: The data to send to the client. Data can be of type
                      ``str``, ``bytes``, ``list`` or ``dict``. If a ``list``
                      or ``dict``, the data will be serialized as JSON.
+        :param binary: ``True`` to send packet as binary, ``False`` to send
+                       as text. If not given, unicode (Python 2) and str
+                       (Python 3) are sent as text, and str (Python 2) and
+                       bytes (Python 3) are sent as binary.
         """
-        self._get_socket(sid).send(packet.Packet(packet.MESSAGE, data=data))
+        self._get_socket(sid).send(packet.Packet(packet.MESSAGE, data=data,
+                                                 binary=binary))
 
     def close(self, sid=None):
         """Close a client connection.
@@ -208,19 +212,22 @@ class Server(object):
     def _handle_connect(self, environ):
         """Handle a client connection request."""
         sid = self.generate_id()
-        if self._trigger_event('connect', sid, environ) is False:
-            self.logger.warning('Application rejected connection')
-            return self._unauthorized()
-        self.clients[sid] = socket.Socket(self, sid)
+        s = socket.Socket(self, sid)
+        self.clients[sid] = s
         pkt = packet.Packet(
             packet.OPEN, {'sid': sid,
                           'upgrades': self._upgrades(sid),
                           'pingTimeout': int(self.ping_timeout * 1000),
                           'pingInterval': int(self.ping_interval * 1000)})
+        s.send(pkt)
+        if self._trigger_event('connect', sid, environ) is False:
+            self.logger.warning('Application rejected connection')
+            del self.clients[sid]
+            return self._unauthorized()
         headers = None
         if self.cookie:
             headers = [('Set-Cookie', self.cookie + '=' + sid)]
-        return self._ok([pkt], headers=headers)
+        return self._ok(s.poll(), headers=headers)
 
     def _upgrades(self, sid):
         """Return the list of possible upgrades for a client connection."""
